{% load cms_tags %}

<fieldset{% if instance.custom_classes %} class="{{ instance.custom_classes }}"{% endif %}>
    {% if instance.legend %}
        <legend>{{ instance.legend }}</legend>
    {% endif %}

    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
</fieldset>
