# Generated by Django 4.2.14 on 2024-08-01 13:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aldryn_forms", "0017_alter_datefieldplugin_cmsplugin_ptr_and_more")
    ]

    operations = [
        migrations.AddField(
            model_name="formplugin",
            name="use_form_action",
            field=models.BooleanField(
                default=False,
                help_text='Use the URL or CMS Page in the form attribute "action".',
                verbose_name="Form action attribute",
            ),
        ),
    ]
