{% extends "admin/aldryn_forms/export.html" %}
{% load i18n %}

{% block aldryn_form_hidden %}
    {{ wizard.management_form }}
    {{ form.non_field_errors }}
{% endblock %}

{% block aldryn_form_buttons %}
    {% if wizard.steps.current == wizard.steps.last %}
        <input type="submit" class="default" value="{% translate 'Export' %}" />
    {% else %}
        <input type="submit" class="default" value="{% translate 'Continue' %}" />
    {% endif %}
{% endblock %}
