# Generated by Django 4.2.6 on 2025-02-12 12:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_forms', '0018_formplugin_use_form_action'),
    ]

    operations = [
        migrations.CreateModel(
            name='SubmittedToBeSent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, editable=False, max_length=255, verbose_name='form name')),
                ('data', models.TextField(blank=True, editable=False)),
                ('recipients', models.TextField(blank=True, editable=False, help_text='People who got a notification when form was submitted.', verbose_name='users notified')),
                ('language', models.CharField(choices=[('cs', 'cs'), ('en', 'en')], default='cs', max_length=10, verbose_name='form language')),
                ('form_url', models.CharField(blank=True, max_length=255, verbose_name='form url')),
                ('sent_at', models.DateTimeField(auto_now_add=True)),
                ('post_ident', models.CharField(blank=True, max_length=64, null=True)),
            ],
            options={
                'verbose_name': 'Submitted form to be sent',
                'verbose_name_plural': 'Submitted forms to be sent',
                'ordering': ['-sent_at'],
            },
        ),
        migrations.AddField(
            model_name='formsubmission',
            name='post_ident',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
    ]
